local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.spells["auto_attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.EnemyDetected, "White", "Pink")
		return x.NoCC
	end,
}

--[[
   _____            _     _                         
  / ____|          | |   | |                        
 | |     ___   ___ | | __| | _____      ___ __  ___ 
 | |    / _ \ / _ \| |/ _` |/ _ \ \ /\ / / '_ \/ __|
 | |___| (_) | (_) | | (_| | (_) \ V  V /| | | \__ \
  \_____\___/ \___/|_|\__,_|\___/ \_/\_/ |_| |_|___/
                                                    
]]

a.spells["charge"] = {
	ID = 100--[[Charge]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
}

a.spells["potion,if=(!talent.avatar.enabled|buff.avatar.up)&buff.battle_cry.up&debuff.colossus_smash.up|target.time_to_die<=26"] = {
	Type = "item",
	ID = 229206--[[Potion of Prolonged Power]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and ((not talent.avatar.enabled or buff.avatar.up_nogcd) and buff.battle_cry.up_nogcd and debuff.colossus_smash.up_nogcd or x.TimeToDie <= 26)
	end,
	FlashColor = "Yellow",
	Continue = true,
	FlashID = {229206--[[Potion of Prolonged Power]], 127844--[[Potion of the Old War]]},
}

a.spells["blood_fury,if=buff.battle_cry.up|target.time_to_die<=16"] = {
	ID = 20572--[[Blood Fury]],
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and (buff.battle_cry.up_nogcd or x.TimeToDie <= 16)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["berserking,if=buff.battle_cry.up|target.time_to_die<=11"] = {
	ID = 26297--[[Berserking]],
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and (buff.battle_cry.up_nogcd or x.TimeToDie <= 11)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["arcane_torrent,if=buff.battle_cry_deadly_calm.down&rage.deficit>40&cooldown.battle_cry.remains"] = {
	ID = 69179--[[Arcane Torrent]],
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and not (buff.battle_cry.up_nogcd and talent.deadly_calm.enabled) and x.RageDeficit > 40 and cooldown.battle_cry.remains_nogcd > 0
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

,"lights_judgment,if=buff.battle_cry.up|target.time_to_die<=11"

a.spells["avatar,if=gcd.remains<0.25&(buff.battle_cry.up|cooldown.battle_cry.remains<15)|target.time_to_die<=20"] = {
	ID = 107574--[[Avatar]],
	Check = function(z)
		return x.ShouldTemporaryBuff and (buff.battle_cry.up_nogcd or cooldown.battle_cry.remains_nogcd < 15 or x.TimeToDie <= 20)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["battle_cry,if=((target.time_to_die>=70|set_bonus.tier20_4pc)&((gcd.remains<=0.5&prev_gcd.1.ravager)|!talent.ravager.enabled&!gcd.remains&target.debuff.colossus_smash.remains>=5&(!cooldown.bladestorm.remains|!set_bonus.tier20_4pc)&(!talent.rend.enabled|dot.rend.remains>4)))|buff.executioners_precision.stack=2&buff.shattered_defenses.up&!gcd.remains&!set_bonus.tier20_4pc"] = {
	ID = 1719--[[Battle Cry]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.ShouldTemporaryBuff and (((x.TimeToDie >= 70 or set_bonus.tier20_4pc) and ((x.GCD > 0 and s.SpellCooldown(152277--[[Ravager]]) >= 58) or not talent.ravager.enabled and debuff.colossus_smash.remains_nogcd >= 5 and (cooldown.bladestorm.remains_nogcd > 0 or not set_bonus.tier20_4pc) and (not talent.rend.enabled or dot.rend.remains_nogcd > 4))) or buff.executioners_precision.stack_nogcd == 2 and buff.shattered_defenses.up_nogcd and not set_bonus.tier20_4pc)
	end,
	NoGCD = true,
	Continue = true,
	FlashColor = "Yellow",
}

,"use_items,if=buff.battle_cry.up&debuff.colossus_smash.up"

--[[
  ______                     _       
 |  ____|                   | |      
 | |__  __  _____  ___ _   _| |_ ___ 
 |  __| \ \/ / _ \/ __| | | | __/ _ \
 | |____ >  <  __/ (__| |_| | ||  __/
 |______/_/\_\___|\___|\__,_|\__\___|
                                     
]]


a.spells["colossus_smash,if=buff.shattered_defenses.down&(buff.battle_cry.down|(buff.executioners_precision.stack=2&(cooldown.battle_cry.remains<1|buff.battle_cry.up)))"] = {
	ID = 167105--[[Colossus Smash]],
	CheckFirst = function(z)
		return buff.shattered_defenses.down and (buff.battle_cry.down or (buff.executioners_precision.stack == 2 and (cooldown.battle_cry.remains < 1 or buff.battle_cry.up)))
	end,
}

a.spells["warbreaker,if=(raid_event.adds.in>90|!raid_event.adds.exists)&cooldown.mortal_strike.remains<=gcd.remains&buff.shattered_defenses.down&buff.executioners_precision.stack=2"] = {
	ID = 209577--[[Warbreaker]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return (s.Boss("target") or x.ActiveEnemies >= 3) and cooldown.mortal_strike.remains <= x.MaxGCD and buff.shattered_defenses.down and buff.executioners_precision.stack == 2
	end,
}

-- actions.execute+=/heroic_charge,if=rage.deficit>=55&(!cooldown.heroic_leap.remains|swing.mh.remains>1.2)&buff.battle_cry.down
--Remove the -- above to run out of melee and charge back in for rage.

a.spells["rend,if=remains<5&cooldown.battle_cry.remains<2&(cooldown.bladestorm.remains<2|!set_bonus.tier20_4pc)"] = {
	ID = 772--[[Rend]],
	CheckFirst = function(z)
		return talent.rend.enabled and x.Rage >= 30 and (dot.rend.remains < 5 and cooldown.battle_cry.remains < 2 and (cooldown.bladestorm.remains < 2 or not set_bonus.tier20_4pc))
	end,
}

a.spells["mortal_strike,if=buff.executioners_precision.stack=2&buff.shattered_defenses.up"] = {
	ID = 12294--[[Mortal Strike]],
	CheckFirst = function(z)
		return buff.executioners_precision.stack == 2 and buff.shattered_defenses.up
	end,
}

a.spells["whirlwind,if=talent.fervor_of_battle.enabled&buff.weighted_blade.stack=3&debuff.colossus_smash.up&buff.battle_cry.down"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return talent.fervor_of_battle.enabled and buff.weighted_blade.stack == 3 and debuff.colossus_smash.up and buff.battle_cry.down
	end,
}

a.spells["overpower,if=rage<40"] = {
	ID = 7384--[[Overpower]],
	RequireBuff = 60503--[[Overpower!]],
	RequireBuffUnit = "player",
	CheckFirst = function(z)
		return x.Rage < 40
	end,
}

a.spells["execute,if=buff.shattered_defenses.down|rage>=40|talent.dauntless.enabled&rage>=36"] = {
	ID = 163201--[[Execute]],
	CheckFirst = function(z)
		return x.Rage >= 10 and (buff.shattered_defenses.down or x.Rage >= 40 or talent.dauntless.enabled and x.Rage >= 36)
	end,
	FlashColor = "Orange",
}

a.spells["bladestorm,interrupt=1,if=(raid_event.adds.in>90|!raid_event.adds.exists|spell_targets.bladestorm_mh>desired_targets)&!set_bonus.tier20_4pc"] = {
	ID = 227847--[[Bladestorm]],
	CheckFirst = function(z)
		return (s.Boss("target") or x.ActiveEnemies > 3) and not set_bonus.tier20_4pc
	end,
}

--[[
                ______ 
     /\        |  ____|
    /  \   ___ | |__   
   / /\ \ / _ \|  __|  
  / ____ \ (_) | |____ 
 /_/    \_\___/|______|
                       
]]


a.spells["warbreaker,if=(cooldown.bladestorm.up|cooldown.bladestorm.remains<=gcd)&(cooldown.battle_cry.up|cooldown.battle_cry.remains<=gcd)"] = {
	ID = 209577--[[Warbreaker]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return (cooldown.bladestorm.up or cooldown.bladestorm.remains <= x.MaxGCD) and (cooldown.battle_cry.up or cooldown.battle_cry.remains <= x.MaxGCD)
	end,
}

a.spells["bladestorm,if=buff.battle_cry.up&!talent.ravager.enabled"] = {
	ID = 227847--[[Bladestorm]],
	CheckFirst = function(z)
		return buff.battle_cry.up and not talent.ravager.enabled
	end,
}

a.spells["ravager,if=talent.ravager.enabled&cooldown.battle_cry.remains<=gcd&debuff.colossus_smash.remains>6"] = {
	ID = 152277--[[Ravager]],
	CheckFirst = function(z)
		return talent.ravager.enabled and cooldown.battle_cry.remains <= x.MaxGCD and debuff.colossus_smash.remains > 6
	end,
}

a.spells["colossus_smash,if=buff.in_for_the_kill.down&talent.in_for_the_kill.enabled"] = {
	ID = 167105--[[Colossus Smash]],
	CheckFirst = function(z)
		return talent.in_for_the_kill.enabled and buff.in_for_the_kill.down
	end,
}

a.spells["colossus_smash,cycle_targets=1,if=debuff.colossus_smash.down&spell_targets.whirlwind<=10"] = {
	ID = 167105--[[Colossus Smash]],
	CheckFirst = function(z)
		return debuff.colossus_smash.down and x.ActiveEnemies <= 10
	end,
}

a.spells["cleave,if=spell_targets.whirlwind>=5"] = {
	ID = 845--[[Cleave]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.Rage >= 10 and x.ActiveEnemies >= 5
	end,
}

a.spells["whirlwind,if=spell_targets.whirlwind>=5&buff.cleave.up"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return  x.Rage >= 30 and x.ActiveEnemies >= 5 and buff.cleave.u
	end,
}

a.spells["whirlwind,if=spell_targets.whirlwind>=7"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return  x.Rage >= 30 and x.ActiveEnemies >= 7
	end,
}

a.spells["rend,cycle_targets=1,if=remains<=duration*0.3&spell_targets.whirlwind<=3"] = {
	ID = 772--[[Rend]],
	CheckFirst = function(z)
		return talent.rend.enabled and x.Rage >= 30 and dot.rend.refreshable and x.ActiveEnemies <= 3
	end,
}

a.spells["cleave"] = {
	ID = 845--[[Cleave]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.Rage >= 10
	end,
}

a.spells["whirlwind"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return  (x.Spec == 1 and x.Rage >= 30) or x.Spec == 2
	end,
}

--[[
   _____ _                      
  / ____| |                     
 | |    | | ___  __ ___   _____ 
 | |    | |/ _ \/ _` \ \ / / _ \
 | |____| |  __/ (_| |\ V /  __/
  \_____|_|\___|\__,_| \_/ \___|
                                
                                ]]


a.spells["colossus_smash,cycle_targets=1,if=debuff.colossus_smash.down"] = {
	ID = 167105--[[Colossus Smash]],
	CheckFirst = function(z)
		return debuff.colossus_smash.down
	end,
}

a.spells["warbreaker,if=raid_event.adds.in>90&buff.shattered_defenses.down"] = {
	ID = 209577--[[Warbreaker]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return --[[raid_event.adds.in>90&]] buff.shattered_defenses.down
	end,
}

a.spells["focused_rage,if=rage.deficit<35&buff.focused_rage.stack<3"] = {
	ID = 207982--[[Focused Rage]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		s.UpdateBuff(207982--[[Focused Rage]])
		return talent.focused_rage.enabled and x.RageDeficit < 35 and buff.focused_rage.stack_nogcd < 3
	end,
	NoGCD = true,
	Continue = true,
	FlashColor = "Yellow",
}

a.spells["rend,cycle_targets=1,if=remains<=duration*0.3"] = {
	ID = 772--[[Rend]],
	CheckFirst = function(z)
		return talent.rend.enabled and x.Rage >= 30 and dot.rend.refreshable
	end,
}

a.spells["mortal_strike"] = {
	ID = 12294--[[Mortal Strike]],
}

a.spells["execute"] = {
	ID = 163201--[[Execute]],
	CheckFirst = function(z)
		return (x.Spec == 1 and x.Rage >= 10) or (x.Spec == 2 and x.Rage >= 25)
	end,
	FlashColor = "Orange",
}

--[[
   _____ _             _        _______                   _   
  / ____(_)           | |      |__   __|                 | |  
 | (___  _ _ __   __ _| | ___     | | __ _ _ __ __ _  ___| |_ 
  \___ \| | '_ \ / _` | |/ _ \    | |/ _` | '__/ _` |/ _ \ __|
  ____) | | | | | (_| | |  __/    | | (_| | | | (_| |  __/ |_ 
 |_____/|_|_| |_|\__, |_|\___|    |_|\__,_|_|  \__, |\___|\__|
                  __/ |                         __/ |         
                 |___/                         |___/          ]]


a.spells["bladestorm,if=buff.battle_cry.up&(set_bonus.tier20_4pc|equipped.the_great_storms_eye)"] = {
	ID = 227847--[[Bladestorm]],
	CheckFirst = function(z)
		return buff.battle_cry.up and (set_bonus.tier20_4pc or equipped.the_great_storms_eye)
	end,
}

a.spells["colossus_smash,if=buff.shattered_defenses.down"] = {
	ID = 167105--[[Colossus Smash]],
	CheckFirst = function(z)
		return buff.shattered_defenses.down
	end,
}

a.spells["warbreaker,if=(raid_event.adds.in>90|!raid_event.adds.exists)&((talent.fervor_of_battle.enabled&debuff.colossus_smash.remains<gcd)|!talent.fervor_of_battle.enabled&((buff.stone_heart.up|cooldown.mortal_strike.remains<=gcd.remains)&buff.shattered_defenses.down))"] = {
	ID = 209577--[[Warbreaker]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
 		return (s.Boss("target") or x.ActiveEnemies >= 3) and ((talent.fervor_of_battle.enabled and debuff.colossus_smash.remains < x.MaxGCD) or not talent.fervor_of_battle.enabled and ((buff.stone_heart.up or cooldown.mortal_strike.remains <= x.MaxGCD) and buff.shattered_defenses.down))
	end,
}

-- actions.single+=/heroic_charge,if=rage.deficit>=55&(!cooldown.heroic_leap.remains|swing.mh.remains>1.2)&buff.battle_cry.down
--Remove the -- above to run out of melee and charge back in for rage.

a.spells["focused_rage,if=!buff.battle_cry_deadly_calm.up&buff.focused_rage.stack<3&!cooldown.colossus_smash.up&(rage>=130|debuff.colossus_smash.down|talent.anger_management.enabled&cooldown.battle_cry.remains<=8)"] = {
	ID = 207982--[[Focused Rage]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		s.UpdateBuff(207982--[[Focused Rage]])
		return talent.focused_rage.enabled and x.Rage >= 20 and (not (buff.battle_cry.up_nogcd and talent.deadly_calm.enabled) and buff.focused_rage.stack_nogcd < 3 and not cooldown.colossus_smash.up_nogcd and (x.Rage >= 130 or debuff.colossus_smash.down_nogcd or talent.anger_management.enabled and cooldown.battle_cry.remains_nogcd <= 8))
	end,
	NoGCD = true,
	Continue = true,
	FlashColor = "Yellow",
}

a.spells["rend,if=remains<=gcd.max|remains<5&cooldown.battle_cry.remains<2&(cooldown.bladestorm.remains<2|!set_bonus.tier20_4pc)"] = {
	ID = 772--[[Rend]],
	CheckFirst = function(z)
		return talent.rend.enabled and x.Rage >= 30 and (dot.rend.remains <= x.MaxGCD or dot.rend.remains < 5 and cooldown.battle_cry.remains < 2 and (cooldown.bladestorm.remains < 2 or not set_bonus.tier20_4pc))
	end,
}

a.spells["ravager,if=cooldown.battle_cry.remains<=gcd&debuff.colossus_smash.remains>6"] = {
	ID = 152277--[[Ravager]],
	CheckFirst = function(z)
		return talent.ravager.enabled and cooldown.battle_cry.remains <= x.MaxGCD and debuff.colossus_smash.remains > 6
	end,
}

a.spells["execute,if=buff.stone_heart.react"] = {
	ID = 163201--[[Execute]],
	CheckFirst = function(z)
		return x.Rage >= 10 and buff.stone_heart.up
	end,
	FlashColor = "Orange",
}

a.spells["overpower,if=buff.battle_cry.down"] = {
	ID = 7384--[[Overpower]],
	RequireBuff = 60503--[[Overpower!]],
	RequireBuffUnit = "player",
	CheckFirst = function(z)
		return talent.overpower.enabled and buff.battle_cry.down
	end,
}

a.spells["mortal_strike,if=buff.shattered_defenses.up|buff.executioners_precision.down"] = {
	ID = 12294--[[Mortal Strike]],
	CheckFirst = function(z)
		return buff.shattered_defenses.up or buff.executioners_precision.down
	end,
}

a.spells["rend,if=remains<=duration*0.3"] = {
	ID = 772--[[Rend]],
	CheckFirst = function(z)
		return talent.rend.enabled and x.Rage >= 30 and dot.rend.refreshable
	end,
}

a.spells["cleave,if=talent.fervor_of_battle.enabled&buff.cleave.down&!equipped.archavons_heavy_hand"] = {
	ID = 845--[[Cleave]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.Rage >= 10 and talent.fervor_of_battle.enabled and buff.cleave.down and not equipped.archavons_heavy_hand
	end,
}

a.spells["whirlwind,if=spell_targets.whirlwind>1|talent.fervor_of_battle.enabled"] = {
	ID = 1680--[[Whirlwind]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return  x.Rage >= 30 and (x.ActiveEnemies > 1 or talent.fervor_of_battle.enabled)
	end,
}

a.spells["slam,if=spell_targets.whirlwind=1&!talent.fervor_of_battle.enabled&(rage>=52|!talent.rend.enabled|!talent.ravager.enabled)"] = {
	ID = 1464--[[Slam]],
	CheckFirst = function(z)
		return x.ActiveEnemies == 1 and not talent.fervor_of_battle.enabled and (x.Rage>=52 or not talent.rend.enabled or not talent.ravager.enabled)
	end,
}

a.spells["overpower"] = {
	ID = 7384--[[Overpower]],
	RequireBuff = 60503--[[Overpower!]],
	RequireBuffUnit = "player",
	CheckFirst = function(z)
		return talent.overpower.enabled
	end,
}

a.spells["bladestorm,if=(raid_event.adds.in>90|!raid_event.adds.exists)&!set_bonus.tier20_4pc"] = {
	ID = 227847--[[Bladestorm]],
	CheckFirst = function(z)
		return s.Boss("target") and not set_bonus.tier20_4pc
	end,
}
